@@ -1223,6 +1223,44 @@ char *pathencode(const char *str){
 }
 
 
+/* Trim invalid characters of an XML string. */
+char *trimxmlchars(char *str) {
+  assert(str);
+  const unsigned char *rp = (unsigned char *)str;
+  unsigned char *wp = (unsigned char *)str;
+  while (*rp != '\0') {
+    int c = 0;
+    int len = 0;
+    if(*rp < 0x80){
+      c = *rp;
+      len = 1;
+    } else if(*rp < 0xe0){
+      if(rp[1] >= 0x80){
+        c = ((rp[0] & 0x1f) << 6) | (rp[1] & 0x3f);
+        len = 2;
+      }
+    } else if(*rp < 0xf0){
+      if(rp[1] >= 0x80 && rp[2] >= 0x80){
+        c = ((rp[0] & 0xf) << 12) | ((rp[1] & 0x3f) << 6) | (rp[2] & 0x3f);
+        len = 3;
+      }
+    }
+    if(len < 1) break;
+    if(c == 0x0A || c == 0x0D || (c >= 0x20 && c <= 0xD7FF) ||
+        false) {
+      while (len-- > 0) {
+        *(wp++) = *(rp++);
+      }
+    } else {
+      *(wp++) = '?';
+      rp += len;
+    }
+  }
+  *wp = '\0';
+  return str;
+}
+
+
 /* Store an article into a database. */
 bool dbputart(TCTDB *tdb, int64_t id, TCMAP *cols){
   assert(tdb && cols);
