@@ -50,7 +50,7 @@ __COMMON_CLINKAGEBEGIN
  *************************************************************************************************/
 
 
-#define TPVERSION      "0.9.19"
+#define TPVERSION      "0.9.20"
 
 #define TUNEBNUM       131071            // bnum tuning parameter
 #define TUNEAPOW       6                 // apow tuning parameter
@@ -152,6 +152,12 @@ const char *mimetypename(const char *type);
 char *pathencode(const char *str);
 
 
+/* Trim invalid characters of an XML string.
+   `str' specifies the string.
+   The return value is the pointer to the given string. */
+char *trimxmlchars(char *str);
+
+
 /* Store an article into the database.
    `tdb' specifies the database object.
    `id' specifies the ID number of the article.  If it is not more than 0, the auto-increment ID
